<?php
/*
Plugin Name: Blog Introduction
Plugin URI: http://jussi.ruokomaki.fi/tech/wp-blog-introduction/
Description: Displays heading and contents of certain page on the home page right before the posts. Hide this special page by making it private.
Author: Jussi Ruokom&auml;ki
Version: 1.3.1
Author URI: http://jussi.ruokomaki.fi/
*/

$blog_introduction_printed = false;

$bintro_page_permalink_data = 'blog-introduction';
add_option('bintro_page_permalink', $bintro_page_permalink_data);
$bintro_page_permalink = get_option('bintro_page_permalink');

$bintro_show_for_data = 'all';
add_option('bintro_show_for', $bintro_show_for_data);
$bintro_show_for = get_option('bintro_show_for');

$bintro_heading_tag_data = 'h2';
add_option('bintro_heading_tag', $bintro_heading_tag_data);
$bintro_heading_tag = get_option('bintro_heading_tag');

$bintro_debug_data = 0;
add_option('bintro_debug', $bintro_debug_data);
$bintro_debug = get_option('bintro_debug');


function bintro_print() { if (is_home()) {
  global $blog_introduction_printed, $bintro_page_permalink, $bintro_show_for, 
    $bintro_heading_tag, $bintro_debug;

  if ($bintro_show_for != 'all') {
    if (($bintro_show_for == 'users' && !is_user_logged_in()) ||
        ($bintro_show_for == 'visitors' && is_user_logged_in())) {
      return false;
    }
  }

  if (!$blog_introduction_printed) {
    if (is_numeric($bintro_page_permalink)) {
      $page = get_page($bintro_page_permalink);
    } else {
      $page = get_page_by_path($bintro_page_permalink);
    }
?>

<?php if ($bintro_debug) { echo '<!--'; } ?>

<div id="blog_introduction">
  <div id="blog_introduction_heading">
      <<?= $bintro_heading_tag ?>><?= $page->post_title ?></<?= $bintro_heading_tag ?>>
  </div>
  <div id="blog_introduction_content">
<?= $page->post_content ?>

  </div>
</div>

<?php if ($bintro_debug) { echo '-->'; } ?>

<?php
  $blog_introduction_printed = true;
} } }


function bintro_add_options_page() {
  add_options_page('Blog Introduction', 'Blog Introduction', 8, basename(__FILE__), 'bintro_options_page');
}

function bintro_options_page() { ?>

<div class="wrap">

  <h2><?= __('Blog Introduction Settings') ?></h2>

  <form method="post" action="options.php">

    <?php wp_nonce_field('update-options'); ?>

    <table border="0" style="vertical-align: top;" cellspacing="10">
      <tr>
       <td style="vertical-align: top;" width="20%"><?= __('Page id/permalink:') ?></td>
       <td style="vertical-align: top;" width="30%"><input type="text" name="bintro_page_permalink" value="<?php echo get_option('bintro_page_permalink'); ?>" /></td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('Enter page id (numeric, e.g. "8") or its permalink (string, e.g. "my-intro-page"). (Page id is shown in the url when you edit the page.)') . '<br />' . __('Default') . ': blog-introduction' ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Wrapper tag for heading:') ?></td>
       <td style="vertical-align: top;"><input type="text" name="bintro_heading_tag" value="<?php echo get_option('bintro_heading_tag'); ?>" /></td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('Enter tag without &lt;angle brackets&gt;.') . '<br />' . __('Default') . ': h2' ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Show blog introduction for:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_show_for" value="all" <?= get_option('bintro_show_for') == 'all' ? 'checked="checked"' : ''  ?> /> <?= __('Everyone') ?><br />
         <input type="radio" name="bintro_show_for" value="users" <?= get_option('bintro_show_for') == 'users' ? 'checked="checked"' : ''  ?> /> <?= __('Authenticated users only') ?><br />
         <input type="radio" name="bintro_show_for" value="visitors" <?= get_option('bintro_show_for') == 'visitors' ? 'checked="checked"' : ''  ?> /> <?= __('Unauthenticated visitors only') ?>
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('To whom the introduction should be shown.') . '<br />' . __('Default') . ': ' . __('Everyone') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Enable debugging mode:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_debug" value="0" <?= get_option('bintro_debug') == '0' ? 'checked="checked"' : ''  ?> /> <?= __('No') ?><br />
         <input type="radio" name="bintro_debug" value="1" <?= get_option('bintro_debug') == '1' ? 'checked="checked"' : ''  ?> /> <?= __('Yes') ?><br />
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __("Please don't enable this if you don't not sure what you're doing.") . '<br />' . __('Default') . ': ' . __('No') ?></span></td>
      </tr>
    </table>

    <input type="hidden" name="action" value="update" />

    <input type="hidden" name="page_options" value="bintro_page_permalink,bintro_heading_tag,bintro_show_for,bintro_debug" />

    <p class="submit">
      <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
    </p>

  </form>

</div>

<?php
}


add_action('loop_start', 'bintro_print');

add_action('admin_menu', 'bintro_add_options_page');
